@@ -840,24 +840,6 @@ class CliImportDebianArtifactTests(BaseCliTests):
         self.assertEqual(artifact.data, expected)
         self.assertEqual(set(artifact.files), {f"pkg_{version}_all.deb"})
 
-    def assertBinaryPackages(
-        self, artifact: LocalArtifact[Any], binnmu: bool = False
-    ) -> None:
-        """Assert that artifact is a deb set with expected metadata."""
-        self.assertEqual(artifact.category, ArtifactCategory.BINARY_PACKAGES)
-        deb_version = "1.0"
-        if binnmu:
-            deb_version += "+b1"
-        expected = {
-            "srcpkg_name": "hello-traditional",
-            "srcpkg_version": "1.0",
-            "version": deb_version,
-            "architecture": "all",
-            "packages": ["pkg"],
-        }
-        self.assertEqual(artifact.data, expected)
-        self.assertEqual(set(artifact.files), {f"pkg_{deb_version}_all.deb"})
-
     def assertUpload(
         self,
         artifact: LocalArtifact[Any],
@@ -943,16 +925,15 @@ class CliImportDebianArtifactTests(BaseCliTests):
         artifacts = self.assert_artifacts_are_uploaded(
             mocked_upload_artifact,
             expected_workspace=workspace,
-            expected_artifacts=3,
+            expected_artifacts=2,
             expected_files=len(files),
             stdout=stdout,
             stderr=stderr,
-            extended_artifacts=[11, 12],
-            related_artifacts=[11, 12],
+            extended_artifacts=[11],
+            related_artifacts=[11],
         )
         self.assertUpload(artifacts[0], {file.name for file in files})
         self.assertBinaryPackage(artifacts[1])
-        self.assertBinaryPackages(artifacts[2])
         mocked_relation_create.assert_has_calls(
             [
                 mock.call(
@@ -967,18 +948,6 @@ class CliImportDebianArtifactTests(BaseCliTests):
                     target_id=11,
                     relation_type="relates-to",
                 ),
-                mock.call(
-                    mock.ANY,
-                    artifact_id=10,
-                    target_id=12,
-                    relation_type="extends",
-                ),
-                mock.call(
-                    mock.ANY,
-                    artifact_id=10,
-                    target_id=12,
-                    relation_type="relates-to",
-                ),
             ]
         )
 
@@ -996,18 +965,17 @@ class CliImportDebianArtifactTests(BaseCliTests):
         artifacts = self.assert_artifacts_are_uploaded(
             mocked_upload_artifact,
             expected_workspace=workspace,
-            expected_artifacts=3,
+            expected_artifacts=2,
             expected_files=len(files),
             stdout=stdout,
             stderr=stderr,
-            extended_artifacts=[11, 12],
-            related_artifacts=[11, 12],
+            extended_artifacts=[11],
+            related_artifacts=[11],
         )
         self.assertUpload(
             artifacts[0], {file.name for file in files}, binnmu=True
         )
         self.assertBinaryPackage(artifacts[1], binnmu=True)
-        self.assertBinaryPackages(artifacts[2], binnmu=True)
 
     def test_import_debian_artifact_mixed_changes(self) -> None:
         """Test import a source+binary upload from a local path."""
@@ -1023,17 +991,16 @@ class CliImportDebianArtifactTests(BaseCliTests):
         artifacts = self.assert_artifacts_are_uploaded(
             mocked_upload_artifact,
             expected_workspace=workspace,
-            expected_artifacts=4,
+            expected_artifacts=3,
             expected_files=len(files),
             stdout=stdout,
             stderr=stderr,
-            extended_artifacts=[11, 12, 13],
-            related_artifacts=[11, 12, 13],
+            extended_artifacts=[11, 12],
+            related_artifacts=[11, 12],
         )
         self.assertUpload(artifacts[0], {file.name for file in files})
         self.assertBinaryPackage(artifacts[1])
-        self.assertBinaryPackages(artifacts[2])
-        self.assertSourcePackage(artifacts[3])
+        self.assertSourcePackage(artifacts[2])
 
     def test_import_debian_artifact_deb(self) -> None:
         """import-debian-artifact imports a .deb directly."""
