@@ -138,7 +138,7 @@ class WorkspaceInCurrentScopeField(SlugRelatedFieldBase[Workspace]):
 
     def get_queryset(self) -> QuerySet[Workspace]:
         """Limit to the current scope."""
-        return Workspace.objects.all().in_current_scope()
+        return Workspace.objects.in_current_scope()
 
     def _get_default_workspace(self) -> Workspace:
         """Get the default workspace."""
@@ -219,9 +219,9 @@ class WorkRequestSerializer(
     ) -> list[int]:
         """Return list of artifact ids created by this work request."""
         return list(
-            work_request.artifact_set.all()
-            .order_by("id")
-            .values_list("id", flat=True)
+            work_request.artifact_set.order_by("id").values_list(
+                "id", flat=True
+            )
         )
 
     def validate(self, data: Any) -> Any:
@@ -558,9 +558,7 @@ class ArtifactSerializerResponse(
         """
         files: dict[str, dict[str, Any]] = {}
 
-        for file_in_artifact in artifact.fileinartifact_set.all().order_by(
-            "path"
-        ):
+        for file_in_artifact in artifact.fileinartifact_set.order_by("path"):
             file = file_in_artifact.file
             data = {
                 "size": file.size,
@@ -1072,3 +1070,16 @@ class CollectionSerializer(
             "data",
             "stats",
         ]
+
+
+class EmitMetricSerializer(serializers.Serializer[Never]):
+    """Serializer for a metric to be emitted."""
+
+    metric_type = serializers.ChoiceField(
+        choices=("counter", "gauge", "summary", "histogram")
+    )
+    name = serializers.CharField()
+    labels = serializers.DictField(
+        child=serializers.CharField(), allow_empty=True
+    )
+    value = serializers.FloatField()
