@@ -15,6 +15,8 @@ from typing import assert_never
 from django.contrib.auth.models import AnonymousUser
 from django.db.models import Q
 
+from debusine.artifacts import SourcePackage
+
 try:
     import pydantic.v1 as pydantic
 except ImportError:
@@ -34,6 +36,7 @@ from debusine.server.workflows import (
 )
 from debusine.server.workflows.models import (
     DebianPipelineWorkflowData,
+    DebianPipelineWorkflowDynamicData,
     MakeSignedSourceWorkflowData,
     PackagePublishWorkflowData,
     PackageUploadWorkflowData,
@@ -45,9 +48,10 @@ from debusine.server.workflows.models import (
 )
 from debusine.tasks.models import (
     BackendType,
-    DebianPipelineWorkflowDynamicData,
     ExtraDebusineRepository,
     ExtraRepository,
+    InputArtifact,
+    InputArtifactSingle,
     LintianFailOnSeverity,
     LookupMultiple,
     LookupSingle,
@@ -84,33 +88,30 @@ class DebianPipelineWorkflow(
         Compute dynamic data for this workflow.
 
         :subject: package name of ``source_artifact``
+        :source_artifact_id: id of the source artifact
         """
-        source_data = workflow_utils.source_package_data(self)
-
-        source_artifact_id = lookup_single(
-            self.data.source_artifact,
-            self.workspace,
-            user=self.work_request.created_by,
-            workflow_root=self.work_request.workflow_root,
-            expect_type=LookupChildType.ARTIFACT,
-        ).artifact.id
+        source_artifact = workflow_utils.source_package(self)
+        source_data = SourcePackage.create_data(source_artifact.data)
 
         return DebianPipelineWorkflowDynamicData(
             subject=source_data.name,
             parameter_summary=f"{source_data.name}_{source_data.version}",
-            input_source_artifact_id=source_artifact_id,
+            input_source_artifact_id=source_artifact.id,
         )
 
-    def get_input_artifacts_ids(self) -> list[int]:
-        """Return a list with the source package (or empty list)."""
-        if (
-            self.dynamic_data is None
-            or (artifact_id := self.dynamic_data.input_source_artifact_id)
-            is None
-        ):
-            return []
-
-        return [artifact_id]
+    def get_input_artifacts(self) -> list[InputArtifact]:
+        """Return workflow input artifacts (the source package)."""
+        return [
+            InputArtifactSingle(
+                lookup=self.data.source_artifact,
+                label="source_artifact",
+                artifact_id=(
+                    self.dynamic_data.input_source_artifact_id
+                    if self.dynamic_data is not None
+                    else None
+                ),
+            )
+        ]
 
     def suite_has_active_indexes(self, suite_lookup: LookupSingle) -> bool:
         """Return True if this suite has an active ``InRelease`` file."""
@@ -309,6 +310,7 @@ class DebianPipelineWorkflow(
                     qa = populate_qa(
                         source_artifact=self.data.source_artifact,
                         binary_artifacts=binary_artifacts,
+                        reference_source_artifact=reference_source.id,
                         enable_regression_tracking=True,
                         reference_qa_results=(
                             self.data.regression_tracking_qa_results
@@ -467,6 +469,7 @@ class DebianPipelineWorkflow(
         source_artifact: LookupSingle,
         binary_artifacts: LookupMultiple,
         package_build_logs: LookupMultiple,
+        reference_source_artifact: LookupSingle | None = None,
         vendor: str,
         codename: str,
         architectures: list[str],
@@ -497,6 +500,7 @@ class DebianPipelineWorkflow(
             source_artifact=source_artifact,
             binary_artifacts=binary_artifacts,
             package_build_logs=package_build_logs,
+            reference_source_artifact=reference_source_artifact,
             vendor=vendor,
             codename=codename,
             architectures=architectures,
