@@ -21,6 +21,7 @@ try:
 except ImportError:
     import pydantic as pydantic  # type: ignore
 
+from debusine.db.models.workspaces import workspace_name_regex
 from debusine.server.tasks.models import PackageUploadTarget
 from debusine.tasks.models import (
     ActionRetryWithDelays,
@@ -28,6 +29,7 @@ from debusine.tasks.models import (
     AutopkgtestNeedsInternet,
     AutopkgtestTimeout,
     BackendType,
+    BaseDynamicTaskData,
     BaseTaskData,
     BlhcFlags,
     DebDiffFlags,
@@ -166,6 +168,12 @@ class SbuildWorkflowData(BaseWorkflowData):
         return values
 
 
+class SbuildWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the Sbuild workflow."""
+
+    source_artifact_id: int | None = None
+
+
 class UpdateEnvironmentsWorkflowTarget(BaseWorkflowData):
     """A target for an update_environments workflow."""
 
@@ -229,6 +237,13 @@ class MakeSignedSourceWorkflowData(BaseWorkflowData):
     sbuild_backend: BackendType = BackendType.AUTO
 
 
+class MakeSignedSourceWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the MakeSignedSource workflow."""
+
+    binary_artifacts_ids: list[int] | None = None
+    signing_template_artifacts_ids: list[int] | None = None
+
+
 class RegressionTrackingWorkflowData(BaseWorkflowData):
     """Common data for workflows that handle regression tracking."""
 
@@ -311,6 +326,14 @@ class AutopkgtestWorkflowData(RegressionTrackingWorkflowData):
     timeout: AutopkgtestTimeout | None = None
 
 
+class AutopkgtestWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the Autopkgtest workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+    context_artifacts_ids: list[int] | None = None
+
+
 class ReverseDependenciesAutopkgtestWorkflowData(
     RegressionTrackingWorkflowData
 ):
@@ -357,6 +380,13 @@ class LintianWorkflowData(RegressionTrackingWorkflowData):
     fail_on_severity: LintianFailOnSeverity = LintianFailOnSeverity.ERROR
 
 
+class LintianWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the Lintian workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+
+
 class DebDiffWorkflowData(BaseWorkflowData):
     """`debdiff` workflow data."""
 
@@ -372,6 +402,15 @@ class DebDiffWorkflowData(BaseWorkflowData):
     arch_all_build_architecture: str = "amd64"
 
 
+class DebDiffWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the DebDiff workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+
+    original_id: int | None = None
+
+
 class BlhcWorkflowData(RegressionTrackingWorkflowData):
     """`blhc` workflow data."""
 
@@ -414,6 +453,10 @@ class QAWorkflowData(RegressionTrackingWorkflowData):
     binary_artifacts: LookupMultiple
     package_build_logs: LookupMultiple | None = None
 
+    # debian_pipeline sets this if enable_regression_tracking is set, but it
+    # wasn't present in older workflows.
+    reference_source_artifact: LookupSingle | None = None
+
     vendor: str
     codename: str
     architectures: list[str] | None = None
@@ -502,6 +545,15 @@ class QAWorkflowData(RegressionTrackingWorkflowData):
         return values
 
 
+class QAWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the QA workflow."""
+
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+    reference_source_artifact_id: int | None = None
+    package_build_logs_ids: list[int] | None = None
+
+
 class QAFailurePolicy(StrEnum):
     """Policy to apply if the QA workflow fails."""
 
@@ -626,6 +678,12 @@ class DebianPipelineWorkflowData(BaseWorkflowData):
         return values
 
 
+class DebianPipelineWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for the DebianPipeline workflow."""
+
+    input_source_artifact_id: int | None = None
+
+
 class PackagePublishWorkflowData(BaseWorkflowData):
     """`package_publish` workflow data."""
 
@@ -655,27 +713,50 @@ class PackagePublishWorkflowData(BaseWorkflowData):
         return values
 
 
-class ExperimentWorkspaceData(BaseWorkflowData):
-    """``create_experiment_workspace`` workflow data."""
+class PackagePublishWorkflowDynamicData(BaseDynamicTaskData):
+    """Dynamic data for PackagePublish workflow."""
 
-    experiment_name: str
+    source_artifact_id: int | None = None
+    binary_artifacts_ids: list[int] | None = None
+    target_suite_id: int | None = None
+
+
+class ChildWorkspaceData(BaseWorkflowData):
+    """``create_child_workspace`` workflow data."""
+
+    prefix: str | None = None
+    suffix: str
     public: bool = True
     owner_group: str | None = None
     workflow_template_names: list[str] = []
     expiration_delay: int | None = 60
 
-    @pydantic.validator("experiment_name")
+    @pydantic.validator("prefix")
     @classmethod
-    def validate_experiment_name(cls, data: str) -> str:
+    def validate_prefix(cls, data: str | None) -> str | None:
         """
-        Validate the experiment name.
+        Validate the prefix.
 
-        Valid characters are the sames as workspace/group names, minus the '-'
+        Valid characters are the same as workspace/group names.
         """
         # In pydantic 1.10 this could be done with constr, but mypy currently
         # complains about their syntax
-        if not re.match(r"^[A-Za-z][A-Za-z0-9+._]*$", data):
-            raise ValueError("experiment name contains invalid characters")
+        if data is not None and not re.match(workspace_name_regex, data):
+            raise ValueError("prefix contains invalid characters")
+        return data
+
+    @pydantic.validator("suffix")
+    @classmethod
+    def validate_suffix(cls, data: str) -> str:
+        """
+        Validate the suffix.
+
+        Valid characters are the same as workspace/group names.
+        """
+        # In pydantic 1.10 this could be done with constr, but mypy currently
+        # complains about their syntax
+        if not re.match(workspace_name_regex, data):
+            raise ValueError("suffix contains invalid characters")
         return data
 
 
