@@ -15,7 +15,10 @@ from debusine.artifacts import SourcePackage
 from debusine.artifacts.models import TaskTypes
 from debusine.client.models import LookupChildType
 from debusine.db.models import Artifact, WorkRequest
-from debusine.server.collections.lookup import lookup_multiple
+from debusine.server.collections.lookup import (
+    artifact_ids,
+    lookup_multiple,
+)
 from debusine.server.workflows import workflow_utils
 from debusine.server.workflows.models import (
     AutopkgtestWorkflowData,
@@ -93,11 +96,7 @@ class QAWorkflow(
                 workflow_root=self.work_request.workflow_root,
                 expect_type=LookupChildType.ARTIFACT_OR_PROMISE,
             )
-            build_logs_artifacts_ids = [
-                result.artifact.id
-                for result in build_logs_results
-                if result.artifact is not None
-            ]
+            build_logs_artifacts_ids = artifact_ids(build_logs_results)
         else:
             build_logs_artifacts_ids = None
 
@@ -105,11 +104,7 @@ class QAWorkflow(
             subject=source_data.name,
             parameter_summary=f"{source_data.name}_{source_data.version}",
             source_artifact_id=source_artifact.id,
-            binary_artifacts_ids=[
-                result.artifact.id
-                for result in binary_artifacts_results
-                if result.artifact is not None
-            ],
+            binary_artifacts_ids=artifact_ids(binary_artifacts_results),
             reference_source_artifact_id=(
                 reference_source_artifact.id
                 if reference_source_artifact is not None
@@ -125,18 +120,18 @@ class QAWorkflow(
                 lookup=self.data.source_artifact,
                 label="source_artifact",
                 artifact_id=(
-                    None
-                    if self.dynamic_data is None
-                    else self.dynamic_data.source_artifact_id
+                    self.dynamic_data.source_artifact_id
+                    if self.dynamic_data is not None
+                    else None
                 ),
             ),
             InputArtifactMultiple(
                 lookup=self.data.binary_artifacts,
                 label="binary_artifacts",
                 artifact_ids=(
-                    None
-                    if self.dynamic_data is None
-                    else self.dynamic_data.binary_artifacts_ids
+                    self.dynamic_data.binary_artifacts_ids
+                    if self.dynamic_data is not None
+                    else None
                 ),
             ),
         ]
@@ -192,7 +187,7 @@ class QAWorkflow(
 
         filtered_binary_artifacts = (
             workflow_utils.filter_artifact_lookup_by_arch(
-                self, self.data.binary_artifacts, architectures
+                self, self.data.binary_artifacts, architectures | {"all"}
             )
         )
 
@@ -292,7 +287,7 @@ class QAWorkflow(
             assert self.data.qa_suite is not None
             self._populate_debdiff(
                 source_artifact=self.data.source_artifact,
-                binary_artifacts=self.data.binary_artifacts,
+                binary_artifacts=filtered_binary_artifacts,
                 vendor=self.data.vendor,
                 codename=self.data.codename,
                 original=self.data.qa_suite,
