@@ -48,6 +48,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
 
         with mock.patch(
             "debusine.server.workflows.noop.NoopWorkflow.callback_test",
@@ -69,6 +70,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
 
         with mock.patch(
             "debusine.server.workflows.noop.NoopWorkflow.callback_test",
@@ -90,6 +92,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
         expected_message = (
             "Orchestrator failed: Unhandled workflow callback step: test"
         )
@@ -151,6 +154,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
 
         with mock.patch.object(ExampleWorkflow, "callback") as mock_callback:
             self.assertTrue(orchestrate_workflow(wr))
@@ -185,6 +189,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
 
         with (
             mock.patch.object(
@@ -204,7 +209,9 @@ class OrchestrateWorkflowTests(TestCase):
 
     def test_workflow_callback_outside_workflow(self) -> None:
         """A workflow callback outside a workflow is skipped."""
-        wr = self.playground.create_internal_task(task_name="workflow")
+        wr = self.playground.create_internal_task(
+            task_name="workflow", mark_pending=True
+        )
         expected_message = "Workflow callback is not contained in a workflow"
 
         with self.assertLogsContains(
@@ -237,6 +244,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
         expected_message = "Failed to configure: 1 validation error"
 
         with (
@@ -270,6 +278,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
         expected_message = (
             f"Failed to compute dynamic data for Workflow/noop ({parent.id}): "
             f"Boom"
@@ -314,6 +323,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
         expected_message = "Orchestrator failed: Boom"
 
         with (
@@ -351,6 +361,7 @@ class OrchestrateWorkflowTests(TestCase):
         wr = WorkRequest.objects.create_workflow_callback(
             parent=parent, step="test"
         )
+        wr.mark_pending()
         expected_message = "Orchestrator failed: AssertionError()"
 
         with (
@@ -648,7 +659,9 @@ class OrchestrateWorkflowTests(TestCase):
 
     def test_wrong_task_type(self) -> None:
         """Attempts to orchestrate non-workflows are logged."""
-        wr = self.playground.create_worker_task(assign_new_worker=True)
+        wr = self.playground.create_worker_task(
+            mark_pending=True, assign_new_worker=True
+        )
         expected_message = "Does not have a workflow orchestrator"
 
         with self.assertLogsContains(
