@@ -106,7 +106,7 @@ class PackageUploadWorkflowTests(WorkflowTestBase[PackageUploadWorkflow]):
             upload = self.playground.create_upload_artifacts(
                 source=False,
                 binary=True,
-                bin_architecture=architecture,
+                binaries=[("hello", architecture)],
             )
             uploads.append(upload.upload)
             for binary in upload.binaries:
