@@ -16,6 +16,7 @@ from debusine.artifacts.models import (
     CollectionCategory,
     TaskTypes,
 )
+from debusine.client.models import RuntimeParameter
 from debusine.db.models import (
     Artifact,
     CollectionItem,
@@ -31,7 +32,10 @@ from debusine.server.workflows import (
     workflow_utils,
 )
 from debusine.server.workflows.base import orchestrate_workflow
-from debusine.server.workflows.models import SbuildWorkflowData
+from debusine.server.workflows.models import (
+    SbuildWorkflowData,
+    SbuildWorkflowDynamicData,
+)
 from debusine.server.workflows.tests.helpers import WorkflowTestBase
 from debusine.tasks import TaskConfigError
 from debusine.tasks.models import (
@@ -39,7 +43,7 @@ from debusine.tasks.models import (
     ActionUpdateCollectionWithArtifacts,
     ActionUpdateCollectionWithData,
     BackendType,
-    BaseDynamicTaskData,
+    InputArtifactSingle,
     SbuildInput,
 )
 from debusine.test.test_utils import create_system_tarball_data
@@ -51,14 +55,17 @@ class SbuildWorkflowTests(
     """Unit tests for SbuildWorkflow class."""
 
     def create_sbuild_template(
-        self, name: str = "sbuild", task_data: dict[str, Any] | None = None
+        self,
+        name: str = "sbuild",
+        static_parameters: dict[str, Any] | None = None,
     ) -> WorkflowTemplate:
         """Create a sbuild WorkflowTemplate."""
         return WorkflowTemplate.objects.create(
             name=name,
             workspace=default_workspace(),
             task_name="sbuild",
-            task_data=task_data or {},
+            static_parameters=static_parameters or {},
+            runtime_parameters=RuntimeParameter.ANY,
         )
 
     def create_sbuild_workflow(
@@ -149,11 +156,54 @@ class SbuildWorkflowTests(
 
         self.assertEqual(
             workflow.compute_dynamic_data(TaskDatabase(wr)),
-            BaseDynamicTaskData(
-                subject="hello", parameter_summary="hello_1.0-1"
+            SbuildWorkflowDynamicData(
+                subject="hello",
+                parameter_summary="hello_1.0-1",
+                source_artifact_id=source_artifact.id,
             ),
         )
 
+    def test_get_input_artifacts(self) -> None:
+        source_artifact = self.create_source_package(
+            "hello", "1.0", dsc_fields={"Architecture": "all"}
+        )
+        self.playground.create_debian_environment(codename="bookworm")
+        wr = self.playground.create_workflow(
+            task_name="sbuild",
+            task_data=SbuildWorkflowData(
+                input=SbuildInput(source_artifact=source_artifact.id),
+                target_distribution="debian:bookworm",
+                architectures=["all"],
+            ),
+        )
+        wf = self.get_workflow(wr)
+
+        self.assertIsNone(wf.dynamic_data)
+        self.assertEqual(
+            wf.get_input_artifacts(),
+            [
+                InputArtifactSingle(
+                    lookup=wf.data.input.source_artifact,
+                    label="input.source_artifact",
+                    artifact_id=None,
+                )
+            ],
+        )
+
+        wf.dynamic_data = wf.build_dynamic_data(TaskDatabase(wr))
+
+        self.assertIsNotNone(wf.dynamic_data)
+        self.assertEqual(
+            wf.get_input_artifacts(),
+            [
+                InputArtifactSingle(
+                    lookup=wf.data.input.source_artifact,
+                    label="input.source_artifact",
+                    artifact_id=source_artifact.id,
+                )
+            ],
+        )
+
     def test_validate_input(self) -> None:
         """Test that validate_input passes a valid case."""
         tarball_item = self.playground.create_debian_environment(
@@ -178,7 +228,12 @@ class SbuildWorkflowTests(
         self.assertEqual(wr.status, WorkRequest.Statuses.PENDING)
 
         o = self.get_workflow(wr)
-        self.assertEqual(workflow_utils.source_package(o), source)
+        self.assertEqual(
+            workflow_utils.source_package(
+                o, configuration_key="input.source_artifact"
+            ),
+            source,
+        )
         self.assertEqual(o.architectures, {"all"})
         self.assertEqual(o._get_environment("amd64"), tarball_item.artifact)
         o.validate_input()
@@ -309,25 +364,25 @@ class SbuildWorkflowTests(
             (
                 "all",
                 {
+                    "build_architecture": "amd64",
                     "build_components": ["all"],
                     "build_profiles": None,
-                    "host_architecture": "amd64",
                 },
             ),
             (
                 "amd64",
                 {
+                    "build_architecture": "amd64",
                     "build_components": ["any"],
                     "build_profiles": None,
-                    "host_architecture": "amd64",
                 },
             ),
             (
                 "s390x",
                 {
+                    "build_architecture": "s390x",
                     "build_components": ["any"],
                     "build_profiles": None,
-                    "host_architecture": "s390x",
                 },
             ),
         ]
@@ -412,8 +467,8 @@ class SbuildWorkflowTests(
         children = list(WorkRequest.objects.filter(parent=wr))
         self.assertEqual(len(children), len(expected_children))
 
-    def test_create_work_request_arch_all_host_architecture(self) -> None:
-        """Test using a non-default `arch_all_host_architecture`."""
+    def test_create_work_request_arch_all_build_architecture(self) -> None:
+        """Test using a non-default `arch_all_build_architecture`."""
         environments = self.playground.create_debian_environments_collection()
         tarballs = {
             arch: self.playground.create_artifact(
@@ -443,7 +498,7 @@ class SbuildWorkflowTests(
                 "backend": BackendType.UNSHARE,
                 "target_distribution": "debian:bookworm",
                 "architectures": ["all", "amd64", "s390x"],
-                "arch_all_host_architecture": "s390x",
+                "arch_all_build_architecture": "s390x",
             },
         )
         self.assertEqual(wr.status, WorkRequest.Statuses.PENDING)
@@ -453,25 +508,25 @@ class SbuildWorkflowTests(
             (
                 "all",
                 {
+                    "build_architecture": "s390x",
                     "build_components": ["all"],
                     "build_profiles": None,
-                    "host_architecture": "s390x",
                 },
             ),
             (
                 "amd64",
                 {
+                    "build_architecture": "amd64",
                     "build_components": ["any"],
                     "build_profiles": None,
-                    "host_architecture": "amd64",
                 },
             ),
             (
                 "s390x",
                 {
+                    "build_architecture": "s390x",
                     "build_components": ["any"],
                     "build_profiles": None,
-                    "host_architecture": "s390x",
                 },
             ),
         ]
@@ -529,7 +584,7 @@ class SbuildWorkflowTests(
             child.task_data,
             {
                 "input": {"source_artifact": source.pk},
-                "host_architecture": "amd64",
+                "build_architecture": "amd64",
                 "build_components": ["any"],
                 "build_profiles": None,
                 "binnmu": None,
@@ -664,7 +719,7 @@ class SbuildWorkflowTests(
             child.task_data,
             {
                 "input": {"source_artifact": source.pk},
-                "host_architecture": "amd64",
+                "build_architecture": "amd64",
                 "build_components": ["any"],
                 "build_profiles": None,
                 "binnmu": None,
@@ -887,7 +942,7 @@ class SbuildWorkflowTests(
                     source_artifact=source_artifact.id,
                 ),
                 target_distribution="debian:experimental",
-                arch_all_host_architecture="amd64",
+                arch_all_build_architecture="amd64",
                 architectures=["all"],
             ),
         )
