@@ -254,8 +254,7 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
 
         self.work_request_id: int | None = None
 
-        # Workspace is used when uploading artifacts.
-        # If it's None: the artifacts are created in the default workspace.
+        # Workspace is used when downloading and uploading artifacts.
         # When the worker instantiates the task it should set
         # self.workspace_name (see issue #186).
         self.workspace_name: str | None = None
@@ -551,7 +550,7 @@ class BaseTask(Generic[TD, DTD], metaclass=ABCMeta):
         try:
             return self.execute()
         except Exception as exc:
-            self.logger.exception("Exception in Task %s", self.name)
+            self.logger.info("Exception in Task %s", self.name, exc_info=True)
             raise exc
 
     def execute(self) -> bool:
@@ -785,8 +784,14 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
         if not self.debusine:
             raise AssertionError("self.debusine not set")
 
+        if not self.workspace_name:  # Required for cross-scope artifacts
+            raise AssertionError("self.workspace_name not set")
+
         artifact_response = self.debusine.download_artifact(
-            artifact_id, destination, tarball=False
+            artifact_id,
+            destination,
+            tarball=False,
+            workspace=self.workspace_name,
         )
         self._source_artifacts_ids.append(artifact_id)
         return artifact_response
@@ -924,7 +929,7 @@ class BaseExternalTask(BaseTask[TD, DTD], Generic[TD, DTD], metaclass=ABCMeta):
                     self.cleanup()
                 except Exception as exc:
                     self._log_exception(exc, stage="post_execution")
-                    return False
+                    execution_succeeded = False
 
         if execution_succeeded:
             # We mainly care about stages.log for failures.  It's rather
@@ -1138,8 +1143,11 @@ class BaseTaskWithExecutor(BaseExternalTask[TDE, DTDE], Generic[TDE, DTDE]):
         assert self.debusine
         assert self.dynamic_data
         assert self.dynamic_data.environment_id
+        assert self.workspace_name
         self.executor = executor_class(self.backend)(
-            self.debusine, self.dynamic_data.environment_id
+            self.debusine,
+            self.dynamic_data.environment_id,
+            workspace=self.workspace_name,
         )
         self.executor.download_image()
 
