@@ -38,6 +38,7 @@ from debusine.utils import DjangoChoicesEnum
 class WorkerType(DjangoChoicesEnum):
     """The type of a Worker."""
 
+    SCHEDULER = "scheduler"
     EXTERNAL = "external"
     CELERY = "celery"
     SIGNING = "signing"
@@ -1439,12 +1440,6 @@ class MergeUploadsDynamicData(BaseDynamicTaskData):
     input_uploads_ids: list[int]
 
 
-class DebianPipelineWorkflowDynamicData(BaseDynamicTaskData):
-    """Dynamic data for the DebianPipeline workflow."""
-
-    input_source_artifact_id: int | None = None
-
-
 @dataclass(frozen=True)
 class InputArtifactSingle:
     """Represent a declared single input artifact for a task."""
