@@ -42,8 +42,10 @@ from debusine.tasks.models import (
 from debusine.test.django import TestCase
 from debusine.web.views.autopkgtest import (
     AutopkgtestLogParser,
+    AutopkgtestTab,
     AutopkgtestViewWorkRequestPlugin,
 )
+from debusine.web.views.work_request import Tab
 
 
 class AutopkgtestViewWorkRequestPluginTests(TestCase):
@@ -74,6 +76,18 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             create_files=True,
         )
 
+    def get_tab(self, work_request: WorkRequest) -> AutopkgtestTab:
+        """Return the tab for a work request or a plugin."""
+        plugin = AutopkgtestViewWorkRequestPlugin(work_request)
+        tabs: list[Tab] = []
+        plugin.add_tabs(tabs)
+        self.assertEqual(len(tabs), 1)
+        tab = tabs[0]
+        assert isinstance(tab, AutopkgtestTab)
+        self.assertEqual(tab.name, "autopkgtest")
+        self.assertEqual(tab.label, "Autopkgtest")
+        return tab
+
     def create_work_request_for_artifacts(
         self,
         environment_artifact: Artifact,
@@ -181,9 +195,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         ).dict()
         work_request.save()
         result_artifact = self.create_autopkgtest_artifact(work_request)
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
-
+        context_data = self.get_tab(work_request).get_context_data()
         self.assertEqual(
             context_data,
             {
@@ -233,11 +245,6 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
                     ("command1", "PASS", None),
                     ("command2", "FAIL", "partial"),
                 ],
-                "specialized_tab": {
-                    "label": "Autopkgtest",
-                    "slug": "autopkgtest",
-                    "template": "web/_autopkgtest-work_request-detail.html",
-                },
             },
         )
 
@@ -265,8 +272,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             ],
         ).dict()
         work_request.save()
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        context_data = self.get_tab(work_request).get_context_data()
 
         self.assertEqual(
             context_data["request_data"]["context_artifacts"],
@@ -290,19 +296,15 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         work_request: WorkRequest = self.create_work_request_for_artifacts(
             self.environment_artifact, self.source_artifact, []
         )
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
-        self.assertCountEqual(
-            context_data.keys(), {"request_data", "result", "specialized_tab"}
-        )
+        context_data = self.get_tab(work_request).get_context_data()
+        self.assertCountEqual(context_data.keys(), {"request_data", "result"})
 
     def test_context_data_no_dynamic_task_data(self) -> None:
         """If there is no dynamic data, context data omits artifact info."""
         work_request: WorkRequest = self.create_work_request_for_artifacts(
             self.environment_artifact, self.source_artifact, []
         )
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        context_data = self.get_tab(work_request).get_context_data()
         self.assertIsNone(context_data["request_data"]["codename"])
         self.assertIsNone(context_data["request_data"]["vendor"])
         self.assertEqual(
@@ -334,8 +336,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         ).dict()
         work_request.save()
         environment_artifact.delete()
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        context_data = self.get_tab(work_request).get_context_data()
         self.assertIsNone(context_data["request_data"]["codename"])
         self.assertIsNone(context_data["request_data"]["vendor"])
         self.assertEqual(
@@ -358,8 +359,8 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             input_binary_artifacts_ids=[],
         ).dict()
         work_request.save()
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        tab = self.get_tab(work_request)
+        context_data = tab.get_context_data()
         self.assertIsNone(context_data["request_data"]["codename"])
         self.assertIsNone(context_data["request_data"]["vendor"])
         self.assertEqual(
@@ -380,8 +381,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         source_artifact_id = self.source_artifact.id
         self.source_artifact.files.clear()
         self.source_artifact.delete()
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        context_data = self.get_tab(work_request).get_context_data()
         self.assertEqual(
             context_data["request_data"]["source_artifact"],
             {
@@ -405,8 +405,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
             input_binary_artifacts_ids=[],
         ).dict()
         work_request.save()
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        context_data = self.get_tab(work_request).get_context_data()
         self.assertIsNone(context_data["request_data"]["source_name"])
         self.assertIsNone(context_data["request_data"]["source_version"])
         self.assertEqual(
@@ -437,8 +436,8 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         binary_artifact_1_id = binary_artifact_1.id
         binary_artifact_1.files.clear()
         binary_artifact_1.delete()
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        tab = self.get_tab(work_request)
+        context_data = tab.get_context_data()
         self.assertEqual(
             context_data["request_data"]["binary_artifacts"],
             {
@@ -477,9 +476,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         ).dict()
         work_request.save()
 
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
-
+        context_data = self.get_tab(work_request).get_context_data()
         self.assertEqual(
             context_data["request_data"]["source_artifact"]["files"], []
         )
@@ -617,9 +614,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         for fail_on, expected_scenarios in sub_tests:
             with self.subTest(fail_on=fail_on):
                 self.assertEqual(
-                    AutopkgtestViewWorkRequestPlugin._get_fail_on_scenarios(
-                        fail_on
-                    ),
+                    AutopkgtestTab._get_fail_on_scenarios(fail_on),
                     expected_scenarios,
                 )
 
@@ -630,8 +625,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         )
 
         # Try unconfigured
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        context_data = self.get_tab(work_request).get_context_data()
         self.assertEqual(
             context_data["request_data"]["build_architecture"], "amd64"
         )
@@ -640,8 +634,7 @@ class AutopkgtestViewWorkRequestPluginTests(TestCase):
         work_request.configured_task_data = work_request.task_data.copy()
         work_request.configured_task_data["build_architecture"] = "arm64"
         work_request.save()
-        autopkgtest_view = AutopkgtestViewWorkRequestPlugin(work_request)
-        context_data = autopkgtest_view.get_context_data()
+        context_data = self.get_tab(work_request).get_context_data()
         self.assertEqual(
             context_data["request_data"]["build_architecture"], "arm64"
         )
